epistoch.experimental package
=============================

Submodules
----------

epistoch.experimental.sir\_gen\_experimental module
---------------------------------------------------

.. automodule:: epistoch.experimental.sir_gen_experimental
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: epistoch.experimental
    :members:
    :undoc-members:
    :show-inheritance:
